@@ -1,4 +1,8 @@
-from colorama import init, deinit, Fore, Style
+from __future__ import annotations
+
+from typing import Iterable, TextIO, Type, TYPE_CHECKING
+
+from colorama import Fore, Style
 from colorama.ansi import Cursor
 from colorama.initialise import wrap_stream
 import logging
@@ -8,14 +12,17 @@ import re
 import sys
 from unidecode import unidecode
 
+if TYPE_CHECKING:
+    from colorama.ansitowin32 import StreamWrapper
+
 global debug_level
 debug_level = 0
 
-text_type = str
+text_type: Type[str] = str
 unicode = None  # so pyflakes stops complaining
 
 
-def debug(message, level=1):
+def debug(message: str, level: int = 1) -> None:
     """
     So we can tune how much debug output we get when we turn it on.
     """
@@ -28,73 +35,72 @@ class Colors:
     A class to centralize wrapping strings in terminal colors.
     """
 
-    def __init__(self, termcolor=None):
-        """
-        termcolor - If None, attempt to autodetect whether we are in a terminal
-            and turn on terminal colors if we think we are.  If True, force
-            terminal colors on.  If False, force terminal colors off.
-        """
-        if termcolor is None:
-            self.termcolor = sys.stdout.isatty()
-        else:
-            self.termcolor = termcolor
+    def __init__(self, termcolor: bool | None = None) -> None:
+        """Initialize the Colors object.
 
-    def wrap(self, text, style):
+        Args:
+            termcolor: If None, attempt to autodetect whether we are in a
+                terminal and turn on terminal colors if we think we are.
+                If True, force terminal colors on.
+                If False, force terminal colors off.
+        """
+        self.termcolor = sys.stdout.isatty() if termcolor is None else termcolor
+
+    def wrap(self, text: str, style: str) -> str:
         if self.termcolor:
             return f"{style}{text}{Style.RESET_ALL}"
-        else:
-            return text
+        return text
 
     # Movement
-    def start_of_line(self):
+    def start_of_line(self) -> str:
         return "\r"
 
-    def up(self, lines=1):
+    def up(self, lines: int = 1) -> str:
         return Cursor.UP(lines)
 
     # Real colors and styles
-    def bold(self, text):
+    def bold(self, text: str) -> str:
         return self.wrap(text, Style.BRIGHT)
 
-    def blue(self, text):
+    def blue(self, text: str) -> str:
         if platform.system() == "Windows":  # pragma: no cover
             # Default blue in windows is unreadable (such awful defaults...)
             return self.wrap(text, Fore.CYAN)
         else:
             return self.wrap(text, Fore.BLUE)
 
-    def green(self, text):
+    def green(self, text: str) -> str:
         return self.wrap(text, Fore.GREEN)
 
-    def red(self, text):
+    def red(self, text: str) -> str:
         return self.wrap(text, Fore.RED)
 
-    def yellow(self, text):
+    def yellow(self, text: str) -> str:
         return self.wrap(text, Fore.YELLOW)
 
     # Abstracted colors and styles
-    def passing(self, text):
+    def passing(self, text: str) -> str:
         return self.green(text)
 
-    def failing(self, text):
+    def failing(self, text: str) -> str:
         return self.red(text)
 
-    def error(self, text):
+    def error(self, text: str) -> str:
         return self.red(text)
 
-    def skipped(self, text):
+    def skipped(self, text: str) -> str:
         return self.blue(text)
 
-    def unexpectedSuccess(self, text):
+    def unexpectedSuccess(self, text: str) -> str:
         return self.yellow(text)
 
-    def expectedFailure(self, text):
+    def expectedFailure(self, text: str) -> str:
         return self.yellow(text)
 
-    def moduleName(self, text):
+    def moduleName(self, text: str) -> str:
         return self.bold(text)
 
-    def className(self, text):
+    def className(self, text: str) -> str:
         return text
 
 
@@ -111,19 +117,19 @@ class GreenStream:
            writelines(lines)
     """
 
-    indent_spaces = 2
-    _ascii_only_output = False  # default to printing output in unicode
+    indent_spaces: int = 2
+    _ascii_only_output: bool = False  # default to printing output in unicode
     coverage_pattern = re.compile(r"TOTAL\s+\d+\s+\d+\s+(?P<percent>\d+)%")
 
     def __init__(
         self,
-        stream,
-        override_appveyor=False,
-        disable_windows=False,
-        disable_unidecode=False,
-    ):
+        stream: TextIO,
+        override_appveyor: bool = False,
+        disable_windows: bool = False,
+        disable_unidecode: bool = False,
+    ) -> None:
         self.disable_unidecode = disable_unidecode
-        self.stream = stream
+        self.stream: TextIO | StreamWrapper = stream
         # Ironically, Windows CI platforms such as GitHub Actions and AppVeyor don't support windows
         # win32 system calls for colors, but it WILL interpret posix ansi escape codes! (The
         # opposite of an actual windows command prompt)
@@ -135,7 +141,7 @@ class GreenStream:
         if override_appveyor or (
             (on_windows and not on_windows_ci) and not disable_windows
         ):  # pragma: no cover
-            self.stream = wrap_stream(self.stream, None, None, None, True)
+            self.stream = wrap_stream(stream, None, None, False, True)
             # set output is ascii-only
             self._ascii_only_output = True
         self.closed = False
@@ -147,23 +153,23 @@ class GreenStream:
         # Susceptible to false-positives if other matching lines are output,
         # so set this to None immediately before running a coverage report to
         # guarantee accuracy.
-        self.coverage_percent = None
+        self.coverage_percent: int | None = None
 
-    def flush(self):
+    def flush(self) -> None:
         self.stream.flush()
 
-    def writeln(self, text=""):
+    def writeln(self, text: str = "") -> None:
         self.write(text + "\n")
 
-    def write(self, text):
-        if type(text) == bytes:
+    def write(self, text: str) -> None:
+        if isinstance(text, bytes):
             text = text.decode("utf-8")
         # Compensate for windows' anti-social unicode behavior
         if self._ascii_only_output and not self.disable_unidecode:
             # Windows doesn't actually want unicode, so we get
             # the closest ASCII equivalent
             text = text_type(unidecode(text))
-        # Since coverage doesn't like us switching out it's stream to run extra
+        # Since coverage doesn't like us switching out its stream to run extra
         # reports to look for percent covered. We should replace this with
         # grabbing the percentage directly from coverage if we can figure out
         # how.
@@ -174,14 +180,14 @@ class GreenStream:
                 self.coverage_percent = int(percent_str)
         self.stream.write(text)
 
-    def writelines(self, lines):
+    def writelines(self, lines: Iterable[str]) -> None:
         """
         Just for better compatibility with real file objects
         """
         for line in lines:
             self.write(line)
 
-    def formatText(self, text, indent=0, outcome_char=""):
+    def formatText(self, text: str, indent: int = 0, outcome_char: str = "") -> str:
         # We'll go through each line in the text, modify it, and store it in a
         # new list
         updated_lines = []
@@ -197,7 +203,7 @@ class GreenStream:
         output = "\n".join(updated_lines)
         return output
 
-    def formatLine(self, line, indent=0, outcome_char=""):
+    def formatLine(self, line: str, indent: int = 0, outcome_char: str = "") -> str:
         """
         Takes a single line, optionally adds an indent and/or outcome
         character to the beginning of the line.
@@ -205,7 +211,7 @@ class GreenStream:
         actual_spaces = (indent * self.indent_spaces) - len(outcome_char)
         return outcome_char + " " * actual_spaces + line
 
-    def isatty(self):
+    def isatty(self) -> bool:
         """
         Wrap internal self.stream.isatty.
         """
